@@ -25,6 +25,7 @@ import time
 from adspygoogle.common import SanityCheck
 from adspygoogle.common import Utils
 from adspygoogle.common.Client import Client
+from adspygoogle.common.Errors import ApiVersionNotSupportedError
 from adspygoogle.common.Errors import AuthTokenError
 from adspygoogle.common.Errors import ValidationError
 from adspygoogle.common.Logger import Logger
@@ -238,18 +239,24 @@ class DfpClient(Client):
     """
     if version is None:
       version = DEFAULT_API_VERSION
-    if Utils.BoolTypeConvert(self._config['strict']):
-      DfpSanityCheck.ValidateServer(server, version)
 
-    # Load additional configuration data.
-    if op_config is None:
-      op_config = {
-          'server': server,
-          'version': version,
-          'http_proxy': http_proxy
-      }
-    return GenericDfpService(self._headers, self._config, op_config,
-                             self.__lock, self.__logger, service_name)
+    if 'authToken' in self._headers and version > 'v201311':
+      raise ApiVersionNotSupportedError('ClientLogin is not supported for '
+                                        'version %s, please upgrade to '
+                                        'OAuth2' % version)
+    else:
+      if Utils.BoolTypeConvert(self._config['strict']):
+        DfpSanityCheck.ValidateServer(server, version)
+
+      # Load additional configuration data.
+      if op_config is None:
+        op_config = {
+            'server': server,
+            'version': version,
+            'http_proxy': http_proxy
+        }
+      return GenericDfpService(self._headers, self._config, op_config,
+                               self.__lock, self.__logger, service_name)
 
   def GetCompanyService(self, server='https://www.google.com', version=None,
                         http_proxy=None):
